@@ -1,12 +1,13 @@
 package Org::Element;
 
+our $DATE = '2015-03-14'; # DATE
+our $VERSION = '0.44'; # VERSION
+
 use 5.010;
 use locale;
 use Log::Any '$log';
 use Moo;
-use Scalar::Util qw(refaddr reftype);
-
-our $VERSION = '0.43'; # VERSION
+use Scalar::Util qw(refaddr);
 
 has document => (is => 'rw');
 has parent => (is => 'rw');
@@ -118,6 +119,20 @@ sub headline {
     $h;
 }
 
+sub headlines {
+    my ($self) = @_;
+    my @res;
+    $self->walk_parents(
+        sub {
+            my ($el, $p) = @_;
+            if ($p->isa('Org::Element::Headline')) {
+                push @res, $p;
+            }
+            1;
+        });
+    @res;
+}
+
 sub field_name {
     my ($self) = @_;
 
@@ -164,7 +179,7 @@ Org::Element - Base class for Org document elements
 
 =head1 VERSION
 
-This document describes version 0.43 of Org::Element (from Perl distribution Org-Parser), released on 2014-12-01.
+This document describes version 0.44 of Org::Element (from Perl distribution Org-Parser), released on 2015-03-14.
 
 =head1 SYNOPSIS
 
@@ -233,7 +248,13 @@ document), or until CODEREF returns a false value. CODEREF will be supplied
 
 =head2 $el->headline() => ELEMENT
 
-Get current headline.
+Get current headline. Return undef if element is not under any headline.
+
+=head2 $el->headlines() => ELEMENTS
+
+Get current headline (in the first element of the result list), its parent, its
+parent's parent, and so on until the topmost headline. Return empty list if
+element is not under any headline.
 
 =head2 $el->field_name() => STR
 
@@ -255,7 +276,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
+Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
@@ -271,7 +292,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
